==> haskell-easy-file-0.2.5-120.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-easy-file.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-9f5Z4LqDkdpW7ARL5ow56
key:                  easy-file-0.2.5-9f5Z4LqDkdpW7ARL5ow56
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  08122a0cb2e2b0093fb4398f9418eaa9
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-9f5Z4LqDkdpW7ARL5ow56
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 time-1.12.2
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-easy-file-0.2.5-121-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-easy-file.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-IIC9DtzJ1XTGBMnNCDpijr
key:                  easy-file-0.2.5-IIC9DtzJ1XTGBMnNCDpijr
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  0aaa40741e03dc69e5cfe9af50724636
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-IIC9DtzJ1XTGBMnNCDpijr
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 time-1.12.2
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
